/***************************************************************************
 *   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/
#ifndef PAPYRUSCONTROLLER_H
#define PAPYRUSCONTROLLER_H

#include <sigc++/sigc++.h>

#include <papyrus/smart_pointer.h>
#include <papyrus/event.h>

namespace Papyrus {

/**
 * @author Rick L Vinyard Jr <rvinyard@cs.nmsu.edu>
 */
class Controller {
public:

  typedef PapyrusSmartPointer<Controller> pointer;

    Controller();

    virtual ~Controller();

    virtual bool is_disabled();

    virtual bool disable(bool value=true);

    virtual bool enable(bool value=true);

    sigc::signal<void,bool> signal_disabled();

    virtual bool handle(const Event::Event& event);
    virtual bool handle(const Event::Button& event);
    virtual bool handle(const Event::ButtonPress& event);
    virtual bool handle(const Event::ButtonDoublePress& event);
    virtual bool handle(const Event::ButtonTriplePress& event);
    virtual bool handle(const Event::ButtonRelease& event);
    virtual bool handle(const Event::Key& event);
    virtual bool handle(const Event::KeyPress& event);
    virtual bool handle(const Event::KeyRelease& event);
    virtual bool handle(const Event::Motion& event);
    virtual bool handle(const Event::Scroll& event);

protected:
  bool m_disabled;

  sigc::signal<void,bool> m_signal_disabled;

  virtual bool on_button_press(const Event::ButtonPress& event);
  virtual bool on_button_double_press(const Event::ButtonDoublePress& event);
  virtual bool on_button_triple_press(const Event::ButtonTriplePress& event);
  virtual bool on_button_release(const Event::ButtonRelease& event);
  virtual bool on_key_press(const Event::KeyPress& event);
  virtual bool on_key_release(const Event::KeyRelease& event);
  virtual bool on_motion(const Event::Motion& event);
  virtual bool on_scroll(const Event::Scroll& event);

};

}

#endif
