/***************************************************************************
*   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#ifndef PAPYRUSFREEHANDSKETCHER_H
#define PAPYRUSFREEHANDSKETCHER_H

#include <set>

#include <papyrus/smart_pointer.h>
#include <papyrus/linestyle.h>
#include <papyrus/controller.h>
#include <papyrus/group.h>
#include <papyrus/polygon.h>

namespace Papyrus {

typedef enum SKETCH {
  SKETCH_LINE,
  SKETCH_POLYGON
} SKETCH;

/**
 * @author Rick L Vinyard Jr <rvinyard@cs.nmsu.edu>
 */
class FreehandSketcher: public Controller {
public:
  typedef PapyrusSmartPointer<FreehandSketcher> pointer;
  typedef std::set<Group::pointer> Sketchpads;

  FreehandSketcher(SKETCH mode=SKETCH_LINE, const LineStyle& linestyle=LineStyle());

  static FreehandSketcher::pointer create( SKETCH mode=SKETCH_LINE, const LineStyle& linestyle=LineStyle() );

    virtual ~FreehandSketcher();

    const Sketchpads& sketchpads();
    void add_sketchpad( Group::pointer sketchpad );
    void remove_sketchpad( Group::pointer sketchpad );

    SKETCH sketch_mode();
    void set_sketch_mode(SKETCH mode);

    LineStyle& line_style();
    void set_line_style( const LineStyle& line_style );

    Cairo::RefPtr<Cairo::Pattern> get_fill();
    void set_fill(Cairo::RefPtr<Cairo::Pattern> fill);

    void set_movement_threshhold(double t);
    double get_movement_threshhold();

protected:
  typedef std::map< Group::pointer, Polyline::pointer > Lines;

  SKETCH m_mode;
  LineStyle m_line_style;
  Lines m_lines;
  Papyrus::Polyline::pointer m_current_line;
  Sketchpads m_sketchpads;
  bool m_drawing;
  double m_last_position[2], m_movement_threshhold;
    Cairo::RefPtr<Cairo::Pattern> m_fill;

    virtual bool on_button_press(const Event::ButtonPress& event);
    virtual bool on_button_release(const Event::ButtonRelease& event);
    virtual bool on_motion(const Event::Motion& event);

};

}

#endif
