/* Rotator
 *
 */

#include "gtkmm.h"

#include <papyrus.h>
#include <papyrusmm/viewport.h>

class Example_Rotator : public Gtk::Window
{
  public:
    Example_Rotator();
    virtual ~Example_Rotator();

  protected:
  //Member widgets:
    PapyrusGtk::Viewport m_Viewport;
    Papyrus::Rotator::pointer m_Rotator;
    Papyrus::Boxed::pointer m_boxed;

    Gtk::Adjustment m_rotate_interval_adj;
    Gtk::SpinButton m_rotate_interval;

  void on_rotate_interval_changed();
};

//Called by DemoWindow;
Gtk::Window* do_Rotator()
{
  return new Example_Rotator();
}

Example_Rotator::Example_Rotator():
  m_rotate_interval_adj( 0.0, 0.0, 2.0 * M_PI, M_PI / 10.0, M_PI / 2.0 ),
  m_rotate_interval( m_rotate_interval_adj )
{
  Gtk::HBox* hbox;
  Gtk::VBox* vbox;

  set_title("Rotator Example");

  m_boxed = Papyrus::Boxed::create( );
  m_boxed->get_box()->set_fill( Cairo::SolidPattern::create_rgba(1.0, 0.85, 1.0, 0.9) );
  m_boxed->get_box()->set_outline( Cairo::SolidPattern::create_rgba(1.0, 0.0, 1.0, 0.9) );

  m_Rotator = Papyrus::Rotator::create( m_Viewport.canvas(), m_boxed );
  m_Viewport.add_controller( m_Rotator );

  m_Viewport.set_size_request( 300, 200 );

  // Create some shapes to add to the group
  Papyrus::Rectangle::pointer rectangle = Papyrus::example_rectangle( );
  Papyrus::Circle::pointer circle = Papyrus::example_circle( );
  Papyrus::Arc::pointer arc = Papyrus::example_arc( );

  // Add the shapes to the group
  m_Viewport.canvas()->add( rectangle );
  m_Viewport.canvas()->add( circle );
  m_Viewport.canvas()->add( arc );
  m_Viewport.canvas()->add( m_boxed );

  // Translate the shapes so they don't necessarily overlap
  rectangle->set_xywh(0, -60, 50, 30);
  circle->set_translate(40, 20);
  circle->set_radius(25);
  arc->set_translate(0, 20);

  vbox = Gtk::manage( new Gtk::VBox() );
  vbox->pack_start( m_Viewport );
  vbox->pack_start( *Gtk::manage( new Gtk::HSeparator() ) );

//   hbox = Gtk::manage( new Gtk::HBox() );
//   hbox->pack_start( *Gtk::manage( new Gtk::Label("Rotation Interval") ) );
//   hbox->pack_start( m_rotate_interval );
//   vbox->pack_start( *hbox );

  this->add( *vbox );

  m_rotate_interval.signal_value_changed().connect( sigc::mem_fun(*this, &Example_Rotator::on_rotate_interval_changed) );

  show_all();
}

Example_Rotator::~Example_Rotator()
{
}

void Example_Rotator::on_rotate_interval_changed()
{
//   m_Rotator->set_radian_interval( m_rotate_interval.get_value() );
}
