/* Animator Frame Interval Widget
 *
 * Controls the interval (in milliseconds) between frames for a group of animators.
 */

#include "gtkmm.h"

#include <papyrus/affineanimator.h>
#include <papyrus/factory.h>
#include <papyrusmm/animatorframeintervalwidget.h>
#include <papyrusmm/viewport.h>

#include <gtkmm.h>

class Example_AnimatorFrameIntervalWidget : public Gtk::Window
{
  public:
    Example_AnimatorFrameIntervalWidget();
    virtual ~Example_AnimatorFrameIntervalWidget();

  protected:
  //Member widgets:
    PapyrusGtk::AnimatorFrameIntervalWidget m_AnimatorFrameIntervalWidget;
    PapyrusGtk::Viewport m_Viewport;
    Papyrus::AffineAnimator m_AffineAnimator;
    Papyrus::Group::pointer m_shape;

    Gtk::VBox m_vbox;
    Gtk::CheckButton m_check;
    Gtk::Button m_reset;

    void on_start_stop();

    void on_reset();
};

//Called by DemoWindow;
Gtk::Window* do_AnimatorFrameIntervalWidget()
{
  return new Example_AnimatorFrameIntervalWidget();
}

Example_AnimatorFrameIntervalWidget::Example_AnimatorFrameIntervalWidget()
{

  m_shape = Papyrus::example_group( true, true );
  m_Viewport.canvas()->add( m_shape );
  m_Viewport.set_size_request( 300, 300 );

  m_AffineAnimator.add( m_shape );
  m_AnimatorFrameIntervalWidget.add( m_AffineAnimator );

  set_title("Animator Frame Interval Widget");
  set_border_width(10);

  m_vbox.pack_start( m_AnimatorFrameIntervalWidget );
  m_vbox.pack_start( *Gtk::manage( new Gtk::HSeparator() ) );
  m_vbox.pack_start( m_check );
  m_vbox.pack_start( m_reset );
  m_vbox.pack_start( m_Viewport );

  m_check.set_label( "Start Animation");
  m_check.signal_toggled().connect( sigc::mem_fun( *this, &Example_AnimatorFrameIntervalWidget::on_start_stop ) );

  m_reset.set_label( "Reset" );
  m_reset.signal_clicked().connect( sigc::mem_fun( *this, &Example_AnimatorFrameIntervalWidget::on_reset ) );

  m_AffineAnimator.set_frame_rate( 20 );
  m_AffineAnimator.set_rotate( M_PI/50 );
  m_AffineAnimator.set_translate( 2.0, -2.0 );
  m_AffineAnimator.set_bounce_frames( 40 );

  this->add( m_vbox );

  show_all();
}

Example_AnimatorFrameIntervalWidget::~Example_AnimatorFrameIntervalWidget()
{
}

void Example_AnimatorFrameIntervalWidget::on_start_stop()
{
  if ( m_check.get_active() )
    m_AffineAnimator.start();
  else
    m_AffineAnimator.stop();
}

void Example_AnimatorFrameIntervalWidget::on_reset()
{
  m_shape->set_rotate( 0.0 );
  m_shape->set_translate( 0.0, 0.0 );
}
